// Listing 3.2 - eList.java

/*
  compile with javac, ensure the CLASSPATH includes the appropriate
  JAXP packages
*/

import java.io.*;
import org.xml.sax.*;  
import javax.xml.parsers.SAXParserFactory;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.SAXParser;

public class EList extends HandlerBase 
{
   public static void main( String fname[] )
   {
      if ( fname.length != 1 ) {
         System.err.println( "Expected Syntax: java EList [filename]\n" );
         System.exit( 1 );
      }

      SAXParserFactory saxFactory = SAXParserFactory.newInstance();

      /*If you wish to have SAX validate an XML document against
			  a DTD, you may change this value to true*/
			saxFactory.setValidating( false );

      try {
         SAXParser saxParser = saxFactory.newSAXParser();
         saxParser.parse( new File( fname[ 0 ] ), new EList() );
      }
      catch ( SAXParseException spe ) {
         System.err.println( "Parse Error: " + spe.getMessage() );
      }
      catch ( SAXException se ) {
         se.printStackTrace();
      }
      catch ( ParserConfigurationException pce ) {
         pce.printStackTrace();
      }
      catch ( IOException ioe ) {
         ioe.printStackTrace();
      }

      System.exit( 0 );
   }
	 

   // print the document URL path and name
   public void setDocumentLocator( Locator fname )
   {
      System.out.println( "Name of Document: " + fname.getSystemId() );
   }

   // SAX Event - Start of Document
   public void startDocument() 
	 throws SAXException
   {
      System.out.println( "SAX Event - Start of Document" );
   }

   // SAX Event - End of Document
   public void endDocument() 
	 throws SAXException
   {
      System.out.println( "SAX Event - End of Document" );
   }

   // SAX Events for Elements and Attributes
   public void startElement( String el_name, AttributeList attr ) 
	 throws SAXException
   {
      System.out.println( "SAX Event - Element Start: " + el_name );
      if ( attr != null ) 
           for ( int i = 0; i < attr.getLength(); i++ )
              System.out.println( "SAX Event - Attribute: " 
              + attr.getName( i ) 
              + "=\"" + attr.getValue( i )
              + "\"" );

	 }

   // SAX Event - Element End
   public void endElement( String el_name ) 
	 throws SAXException
   {
	            System.out.println("SAX Event - Element End: " + el_name );
	 }

   // SAX Event - Character Data and Whitespace characters
   public void characters( char buf [], int offset, int len ) 
	 throws SAXException
   {
      if ( len > 0 ) {
         String stuff = new String( buf, offset, len );

         System.out.println( "SAX Event - Characters: " + stuff );
      }
   }

   // SAX Event - Processing Instructions
   public void processingInstruction( String part1,String part2 ) 
	 throws SAXException
   {
      System.out.println( "SAX Event - Processing Instruction: " 
			   + part1 + " " + part2 );
   }
}